==> nextcloud-26.0.13.zip: nextcloud/apps/circles/l10n/nl.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Je hebt {circle} verwijderd",
    "{author} deleted {circle}" : "{author} verwijderde {circle}",
    "You joined {circle}" : "Je bent lid geworden van {circle}",
    "{member} joined {circle}" : "{member} werd lid van {circle}",
    "You accepted the invitation to join {circle}" : "Je hebt de uitnodiging voor {circle} geaccepteerd",
    "{member} accepted the invitation to join {circle}" : "{member} heeft de uitnodiging voor {circle} geaccepteerd",
    "You added {member} as member to {circle}" : "Jij hebt {member} aan {circle} toegevoegd",
    "You have been added as member to {circle} by {author}" : "Je bent door {author} als lid tot {circle} toegevoegd",
    "{member} has been added as member to {circle} by {author}" : "{member} is door {author} als lid tot {circle} toegevoegd",
    "You added {external} to {circle}" : "Je hebt {external} toegevoegd aan {circle}",
    "{external} has been added to {circle} by {author}" : "{external} is toegevoegd aan {circle} door {author}",
    "You accepted {member}'s request to join {circle}" : "Je accepteerde {member}'s verzoek op lid te worden van {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Je verzoek om lid te worden van {circle} is door {author} geaccepteerd",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}'s verzoek om lid te worden van {circle} is door {author} geaccepteerd",
    "You left {circle}" : "Je hebt {circle} verlaten",
    "{member} left {circle}" : "{member} verliet {circle}",
    "You declined the invitation to join {circle}" : "Je hebt de uitnodiging om lid te worden van {circle} afgewezen",
    "{member} declined an invitation to join {circle}" : "{member} heeft de uitnodiging om lid te worden van {circle} afgewezen",
    "You cancelled your request to join {circle}" : "Je hebt je verzoek om lid te worden van {circle} ingetrokken",
    "You removed {member} from {circle}" : "Je hebt {member} van {circle} verwijderd",
    "You have been removed from {circle} by {author}" : "Je werd van {circle} door {author} verwijderd",
    "{member} has been removed from {circle} by {author}" : "{member} is van {circle} door {author} verwijderd",
    "You removed {external} from {circle}" : "Je hebt {external} verwijderd van {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} is door {author} verwijderd van {circle} ",
    "You cancelled {member}'s invitation to join {circle}" : "Je hebt de uitnodiging voor {member} om lid te worden van {circle} ingetrokken",
    "Your invitation to join {circle} has been cancelled by {author}" : "Je uitnodiging om lid te worden van {circle} is door {author} ingetrokken",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} heeft de uitnodiging voor {member} om lid te worden van {circle} ingetrokken",
    "You dismissed {member}'s request to join {circle}" : "Je het het verzoek van {member}'s om lid te worden van {circle} afgewezen",
    "Your request to join {circle} has been dismissed by {author}" : "Je verzoek om bij {circle} aan te sluiten is door {author} afgewezen",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}'s verzoek om lid te worden van {circle} is door {author} afgewezen",
    "You invited {member} to join {circle}" : "Je nodigde {member} uit om lid te worden van {circle}",
    "You have been invited to join {circle} by {author}" : "Je bent uitgenodigd om lid te worden van {circle} door {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} is uitgenodigd om lid te worden van {circle} door {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Je veranderde {member}'s niveau in {circle} naar %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} veranderde je niveau in {circle} naar %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} veranderde {member}'s niveau van {circle} naar %1$s",
    "You sent a request to join {circle}" : "Je verzoek gestuurd om lid te worden van {circle}",
    "{member} sent a request to join {circle}" : "{member} verzond een verzoek om lid te worden van {circle}",
    "You are the new owner of {circle}" : "Je bent de nieuwe eigenaar van {circle}",
    "{member} is the new owner of {circle}" : "{member} is de nieuwe eigenaar van {circle}",
    "Shared to Circles" : "Gedeeld met Kringen",
    "Single" : "Alleen",
    "Personal" : "Persoonlijk",
    "System" : "Systeem",
    "Visible" : "Zichtbaar",
    "Open" : "Open",
    "Invite" : "Uitnodigen",
    "Friends" : "Vrienden",
    "Password protected" : "Wachtwoord-beveiligd",
    "No Owner" : "Geen eigenaar",
    "Hidden" : "Verborgen",
    "Backend" : "Backend",
    "Local" : "Lokaal",
    "Root" : "Root",
    "Federated" : "Gefedereerd",
    "Mount point" : "Aankoppelpunt",
    "Nextcloud Account" : "Nextcloud Account",
    "Nextcloud Group" : "Nextcloud Groep",
    "Email address" : "E-mailadres",
    "Contact" : "Contact",
    "Circle" : "Kring",
    "Nextcloud App" : "Nextcloud App",
    "Member" : "Lid",
    "Moderator" : "Moderator",
    "Admin" : "Beheerder",
    "Owner" : "Eigenaar",
    "%s shared »%s« with you." : "%sheeft \"%s\" met je gedeeld.",
    "%s shared »%s« with \"%s\"." : "%s deelde \"%s\" met \"%s\".",
    "%s on %s" : "%s op  %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s heeft \"%2$s\" met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s heeft \"%2$s\" met je gedeeld. Je moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
    "Password to access »%1$s« shared to you by %2$s" : "Wachtwoord voor toegang tot \"%1$s\" met jou gedeeld door %2$s",
    "Password to access »%s«" : "Wachtwoord voor toegang \"%s\"",
    "It is protected with the following password:" : "Het is beveiligd met het volgende wachtwoord:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Klik op de button hieronder om te openen.",
    "Open »%s«" : "Open \"%s\"",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s heeft verschillende bestanden met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s heeft verschillende bestanden met je gedeeld. Je moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
    "Password to access files shared to you by %1$s" : "Wachtwoord voor toegang tot bestanden met jou gedeeld door %1$s",
    "Password to access files" : "Wachtwoord voor toegang tot bestanden",
    "%s shared multiple files with \"%s\"." : "%s deelde meerdere bestanden met \"%s\".",
    "%s shared multiple files with you." : "%s deelde meerdere bestanden met jou.",
    "Boot up" : "Opstarten",
    "Nextcloud Initialization" : "Nextcloud Initialisatie",
    "Circles App Initialization" : "Circles App Initialisatie",
    "Fresh installation status" : "Nieuwe installatiestatus",
    "Building Local Database" : "Aanmaken lokale database",
    "Testing Basic Circle Creation" : "Testen basis kringcreatie",
    "Adding local users and moderators" : "Toevoegen lokale gebruikers en moderatoren",
    "Files" : "Bestanden",
    "This feature is not available for personal circles" : "Deze functie is niet beschikbaar voor persoonlijke kringen",
    "This member is not a moderator" : "Dit lid is geen moderator",
    "Insufficient privileges" : "Onvoldoende rechten",
    "This member does not exist" : "Dit lid bestaat niet",
    "Level cannot be changed for this type of member" : "Het niveau van dit type lid kan niet veranderd worden.",
    "You are already a member of this circle" : "Je bent al lid van deze kring",
    "You have been blocked from this circle" : "Je bent geblokkeerd van deze kring",
    "The account is already a member of this circle" : "Dit account is al lid van deze cirkel",
    "The account has already been invited into this circle" : "Dit account is al uitgenodigt voor deze cirkel",
    "You are now a member of the Circle \"%2$s\"" : "Je bent nu lid van Kring \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Je bent uitgenodigd door %1$sin Kring voor  \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s verstuurde een lidmaatschapsverzoek voor Kring \"%2$s\"",
    "Accept" : "Accepteren",
    "Refuse" : "Weigeren",
    "Leave the circle" : "Verlaat de kring",
    "%s" : "%s",
    "%s owned by %s" : "%s is eigendom van %s",
    "%s shared a file with \"%s\"." : "%s deelde een bestand met \"%s\".",
    "%s shared a file with you." : "%s heeft een bestand met u gedeeld",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
    "Password to access content shared with you by %1$s" : "Wachtwoord om toegang te krijgen tot inhoud gedeeld met u door %1$s",
    "Password to access content" : "Wachtwoord voor toegang tot info",
    "Bring cloud-users closer together." : "Breng cloudgebruikers dichter bij elkaar.",
    "No files in here" : "Hier geen bestanden",
    "No entries found in this folder" : "Niets in deze map gevonden",
    "Name" : "Naam",
    "Size" : "Omvang",
    "Modified" : "Gewijzigd",
    "Circles" : "Kringen",
    "Circles' files" : "Kringbestanden",
    "Select circles to filter by" : "Selecteer kring om te filteren",
    "No circles found" : "Geen kringen gevonden",
    "Please select circles to filter by" : "Selecteer kringen om te filteren",
    "No files found for the selected circles" : "Geen bestanden gevonden voor de geselecteerde kringen",
    "You created the circle {circle}" : "Je hebt de kring {circle} gecreëerd",
    "{author} created the circle {circle}" : "{author} maakte de {circle} kring",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Over gebeurtenissen in een <strong>Kring</strong> waarvan je lid bent",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Belangrijke gebeurtenissen in <strong>Kring</strong> die je modereert",
    "On global events happening in any <strong>Circle</strong>" : "Over globale afspraken die gebereuren binnen een <strong>Kring</strong>",
    "Join Request" : "Deelnameverzoek",
    "Password Protected" : "Beveiligd met wachtwoord",
    "Circle Invite" : "Kringuitnodiging",
    "Email Address" : "E-mailadres",
    "Initialisation Nextcloud" : "Initialisatie Nextcloud",
    "Initialisation Circles App" : "Initialisatie Circles App",
    "Circle not found" : "Kring niet gevonden",
    "Circle not found " : "Kring niet gevonden",
    "This account is already a member of the circle" : "Dit account is al lid van de cirkel",
    "Federated link not found" : "Gefedereerde link is niet gevonden",
    "The circle is not federated" : "De kring is niet gefedereerd",
    "You cannot join this circle" : "Je kunt niet lid worden van deze kring",
    "This member is the owner of the circle" : "Dit lid is de eigenaar van de kring",
    "%s (Circle owned by %s)" : "%s (kring is eigendom van %s)",
    "Personal Circle" : "Persoonlijke kring",
    "You need a specify a type of circle" : "Een specifieke kring type is benodigd",
    "A circle with that name exists" : "Er bestaat al een kring met deze naam",
    "This member is not the owner of the circle" : "Dit lid is niet de eigenaar van de kring",
    "This member is not an admin of the circle" : "Dit lid is geen beheerder van de kring",
    "Group contains too many members" : "De groep bevat te veel leden",
    "This group does not exist" : "Deze groep bestaat niet",
    "This group is already linked to the circle" : "Deze groep is al verbonden met de kring",
    "You cannot edit level in a personal circle" : "Je kan het niveau van een persoonlijke kring niet bewerken",
    "Group cannot be set as owner of a circle" : "Een groep kan geen kring eigenaar zijn",
    "now" : "nu",
    "This account does not exist" : "Dit account bestaat niet",
    "Email format is not valid" : "E-mailformaat niet geldig",
    "This contact is not available" : "Deze contact is niet beschikbaar",
    "You have no permission to create a new circle" : "U heeft geen machtiging om een nieuwe kring aan te maken",
    "This item is already shared with this circle" : "Dit object is al gedeeld met deze kring",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Cirkels maakt het mogelijk om zelf groepen te maken met bijvoorbeeld collega's of vrienden.\nDeze gemeenschappen (of \"cirkels\") kunnen vervolgens gebruikt worden door andere applicaties om dingen te delen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.12.zip: nextcloud/apps/circles/l10n/nl.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Teams",
    "You deleted {circle}" : "Je hebt {circle} verwijderd",
    "{author} deleted {circle}" : "{author} verwijderde {circle}",
    "You removed {member} from {circle}" : "Je hebt {member} van {circle} verwijderd",
    "You joined {circle}" : "Je bent lid geworden van {circle}",
    "{member} joined {circle}" : "{member} werd lid van {circle}",
    "You accepted the invitation to join {circle}" : "Je hebt de uitnodiging voor {circle} geaccepteerd",
    "{member} accepted the invitation to join {circle}" : "{member} heeft de uitnodiging voor {circle} geaccepteerd",
    "You added {member} as member to {circle}" : "Jij hebt {member} aan {circle} toegevoegd",
    "You have been added as member to {circle} by {author}" : "Je bent door {author} als lid tot {circle} toegevoegd",
    "{member} has been added as member to {circle} by {author}" : "{member} is door {author} als lid tot {circle} toegevoegd",
    "You added {external} to {circle}" : "Je hebt {external} toegevoegd aan {circle}",
    "{external} has been added to {circle} by {author}" : "{external} is toegevoegd aan {circle} door {author}",
    "You accepted {member}'s request to join {circle}" : "Je accepteerde {member}'s verzoek op lid te worden van {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Je verzoek om lid te worden van {circle} is door {author} geaccepteerd",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}'s verzoek om lid te worden van {circle} is door {author} geaccepteerd",
    "You left {circle}" : "Je hebt {circle} verlaten",
    "{member} left {circle}" : "{member} verliet {circle}",
    "You declined the invitation to join {circle}" : "Je hebt de uitnodiging om lid te worden van {circle} afgewezen",
    "{member} declined an invitation to join {circle}" : "{member} heeft de uitnodiging om lid te worden van {circle} afgewezen",
    "You cancelled your request to join {circle}" : "Je hebt je verzoek om lid te worden van {circle} ingetrokken",
    "You have been removed from {circle} by {author}" : "Je werd van {circle} door {author} verwijderd",
    "{member} has been removed from {circle} by {author}" : "{member} is van {circle} door {author} verwijderd",
    "You removed {external} from {circle}" : "Je hebt {external} verwijderd van {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} is door {author} verwijderd van {circle} ",
    "You cancelled {member}'s invitation to join {circle}" : "Je hebt de uitnodiging voor {member} om lid te worden van {circle} ingetrokken",
    "Your invitation to join {circle} has been cancelled by {author}" : "Je uitnodiging om lid te worden van {circle} is door {author} ingetrokken",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} heeft de uitnodiging voor {member} om lid te worden van {circle} ingetrokken",
    "You dismissed {member}'s request to join {circle}" : "Je het het verzoek van {member}'s om lid te worden van {circle} afgewezen",
    "Your request to join {circle} has been dismissed by {author}" : "Je verzoek om bij {circle} aan te sluiten is door {author} afgewezen",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}'s verzoek om lid te worden van {circle} is door {author} afgewezen",
    "You invited {member} to join {circle}" : "Je nodigde {member} uit om lid te worden van {circle}",
    "You have been invited to join {circle} by {author}" : "Je bent uitgenodigd om lid te worden van {circle} door {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} is uitgenodigd om lid te worden van {circle} door {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Je veranderde {member}'s niveau in {circle} naar %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} veranderde je niveau in {circle} naar %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} veranderde {member}'s niveau van {circle} naar %1$s",
    "You sent a request to join {circle}" : "Je verzoek gestuurd om lid te worden van {circle}",
    "{member} sent a request to join {circle}" : "{member} verzond een verzoek om lid te worden van {circle}",
    "You are the new owner of {circle}" : "Je bent de nieuwe eigenaar van {circle}",
    "{member} is the new owner of {circle}" : "{member} is de nieuwe eigenaar van {circle}",
    "Shared to Circles" : "Gedeeld met Kringen",
    "Single" : "Alleen",
    "Personal" : "Persoonlijk",
    "System" : "Systeem",
    "Visible" : "Zichtbaar",
    "Open" : "Open",
    "Invite" : "Uitnodigen",
    "Friends" : "Vrienden",
    "Password protected" : "Wachtwoord-beveiligd",
    "No Owner" : "Geen eigenaar",
    "Hidden" : "Verborgen",
    "Backend" : "Backend",
    "Local" : "Lokaal",
    "Root" : "Root",
    "Federated" : "Gefedereerd",
    "Mount point" : "Aankoppelpunt",
    "Nextcloud Account" : "Nextcloud Account",
    "Nextcloud Group" : "Nextcloud Groep",
    "Email address" : "E-mailadres",
    "Contact" : "Contact",
    "Circle" : "Kring",
    "Nextcloud App" : "Nextcloud App",
    "Member" : "Lid",
    "Moderator" : "Moderator",
    "Admin" : "Beheerder",
    "Owner" : "Eigenaar",
    "%s shared »%s« with you." : "%sheeft \"%s\" met je gedeeld.",
    "%s shared »%s« with \"%s\"." : "%s deelde \"%s\" met \"%s\".",
    "%s on %s" : "%s op  %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s heeft \"%2$s\" met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s heeft \"%2$s\" met je gedeeld. Je moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
    "Password to access »%1$s« shared to you by %2$s" : "Wachtwoord voor toegang tot \"%1$s\" met jou gedeeld door %2$s",
    "Password to access »%s«" : "Wachtwoord voor toegang \"%s\"",
    "It is protected with the following password:" : "Het is beveiligd met het volgende wachtwoord:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Klik op de button hieronder om te openen.",
    "Open »%s«" : "Open \"%s\"",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s heeft verschillende bestanden met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s heeft verschillende bestanden met je gedeeld. Je moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
    "Password to access files shared to you by %1$s" : "Wachtwoord voor toegang tot bestanden met jou gedeeld door %1$s",
    "Password to access files" : "Wachtwoord voor toegang tot bestanden",
    "%s shared multiple files with \"%s\"." : "%s deelde meerdere bestanden met \"%s\".",
    "%s shared multiple files with you." : "%s deelde meerdere bestanden met jou.",
    "Boot up" : "Opstarten",
    "Nextcloud Initialization" : "Nextcloud Initialisatie",
    "Circles App Initialization" : "Circles App Initialisatie",
    "Fresh installation status" : "Nieuwe installatiestatus",
    "Building Local Database" : "Aanmaken lokale database",
    "Testing Basic Circle Creation" : "Testen basis kringcreatie",
    "Adding local users and moderators" : "Toevoegen lokale gebruikers en moderatoren",
    "Files" : "Bestanden",
    "This feature is not available for personal circles" : "Deze functie is niet beschikbaar voor persoonlijke kringen",
    "This member is not a moderator" : "Dit lid is geen moderator",
    "Insufficient privileges" : "Onvoldoende rechten",
    "This member does not exist" : "Dit lid bestaat niet",
    "Level cannot be changed for this type of member" : "Het niveau van dit type lid kan niet veranderd worden.",
    "You are already a member of this circle" : "Je bent al lid van deze kring",
    "You have been blocked from this circle" : "Je bent geblokkeerd van deze kring",
    "The account is already a member of this circle" : "Dit account is al lid van deze cirkel",
    "The account has already been invited into this circle" : "Dit account is al uitgenodigt voor deze cirkel",
    "Accept" : "Accepteren",
    "Refuse" : "Weigeren",
    "%s" : "%s",
    "%s owned by %s" : "%s is eigendom van %s",
    "%s shared a file with \"%s\"." : "%s deelde een bestand met \"%s\".",
    "%s shared a file with you." : "%s heeft een bestand met u gedeeld",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
    "Password to access content shared with you by %1$s" : "Wachtwoord om toegang te krijgen tot inhoud gedeeld met u door %1$s",
    "Password to access content" : "Wachtwoord voor toegang tot info",
    "Bring cloud-users closer together." : "Breng cloudgebruikers dichter bij elkaar.",
    "No files in here" : "Hier geen bestanden",
    "No entries found in this folder" : "Niets in deze map gevonden",
    "Name" : "Naam",
    "Size" : "Omvang",
    "Modified" : "Gewijzigd",
    "You are now a member of the Circle \"%2$s\"" : "Je bent nu lid van Kring \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Je bent uitgenodigd door %1$sin Kring voor  \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s verstuurde een lidmaatschapsverzoek voor Kring \"%2$s\"",
    "Leave the circle" : "Verlaat de kring"
},
"nplurals=2; plural=(n != 1);");
